/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02778
 |                   GAMBLING IMPACT AND BEHAVIOR STUDY
 |                      (DATASET 0003: COST SURVEY)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02778-0003-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.\n
**********************************************************/


label data "Gambling Impact and Behavior Study, Dataset 0003"

#delimit ;
label define YEAR      -3 "MISSING" ;
label define BINGOIND  -3 "MISSING"
                       0 "FACILITY NOT WITHIN 50 MILES OF COMMUNIT"
                       1 "FACILITY OPENED DURING YEAR"
                       2 "FACILITY WITHIN 50 MILES oF COMMUNITY IN" ;
label define LOTTIND   -3 "MISSING"
                       0 "FACILITY NOT WITHIN 50 MILES OF COMMUNIT"
                       1 "FACILITY OPENED DURING YEAR"
                       2 "FACILITY WITHIN 50 MILES oF COMMUNITY IN" ;
label define PERIMIND  -3 "MISSING"
                       0 "FACILITY NOT WITHIN 50 MILES OF COMMUNIT"
                       1 "FACILITY OPENED DURING YEAR"
                       2 "FACILITY WITHIN 50 MILES oF COMMUNITY IN" ;
label define CASIND    -3 "MISSING"
                       0 "FACILITY NOT WITHIN 50 MILES OF COMMUNIT"
                       1 "FACILITY OPENED DURING YEAR"
                       2 "FACILITY WITHIN 50 MILES oF COMMUNITY IN" ;
label define STFP      -3 "MISSING" ;
label define COFP      -3 "MISSING" ;
label define CASSPEND  -3.0000 "MISSING" ;
label define PERISPND  -3.0000 "MISSING" ;
label define BINGSPND  -3.0000 "MISSING" ;
label define LOTTSPND  -3.0000 "MISSING" ;
label define POP1990   -3 "MISSING" ;
label define PERMRN    -3.0000 "MISSING" ;
label define UCRPOP    -3 "MISSING" ;
label define CRIME     -3 "MISSING" ;
label define MCRIME    -3 "MISSING" ;
label define MURDER    -3 "MISSING" ;
label define RAPE      -3 "MISSING" ;
label define ROBBERY   -3 "MISSING" ;
label define ASSAULT   -3 "MISSING" ;
label define BURGLARY  -3 "MISSING" ;
label define LARCENY   -3 "MISSING" ;
label define MVTHEFT   -3 "MISSING" ;
label define ARSON     -3 "MISSING" ;
label define TOTINC    -3 "MISSING" ;
label define COPOP     -3 "MISSING" ;
label define PERINC    -3 "MISSING" ;
label define EARNCONS  -3 "MISSING" ;
label define EARNTRAN  -3 "MISSING" ;
label define EARNRET   -3 "MISSING" ;
label define EARNGEN   -3 "MISSING" ;
label define EARNEAT   -3 "MISSING" ;
label define EARNSERV  -3 "MISSING" ;
label define EARNHOTL  -3 "MISSING" ;
label define EARNRECR  -3 "MISSING" ;
label define EARNSOCS  -3 "MISSING" ;
label define EARNGOVT  -3 "MISSING" ;
label define EMPLOYED  -3 "MISSING" ;
label define EMPCONST  -3 "MISSING" ;
label define EMPTRANS  -3 "MISSING" ;
label define EMPRETTR  -3 "MISSING" ;
label define EMPSERVC  -3 "MISSING" ;
label define EMPGOVT   -3 "MISSING" ;
label define INCTRANF  -3 "MISSING" ;
label define INCPERMT  -3 "MISSING" ;
label define INCUNEMP  -3 "MISSING" ;
label define INCRETIR  -3 "MISSING" ;
label define INCDVINR  -3 "MISSING" ;
label define PERCAPNT  -3 "MISSING" ;
label define PERCAPTP  -3 "MISSING" ;
label define PERCAPIM  -3 "MISSING" ;
label define PERCAPUI  -3 "MISSING" ;
label define PERCAPRT  -3 "MISSING" ;
label define FEDEXPI   -3 "MISSING" ;
label define FEDEXRTD  -3 "MISSING" ;
label define FEDEXSAL  -3 "MISSING" ;
label define DOCTORS   -3 "MISSING" ;
label define HOSPBEDS  -3 "MISSING" ;
label define CIVLABF   -3 "MISSING" ;
label define UNEMPLOY  -3 "MISSING" ;
label define UNEMPRAT  -3.0 "MISSING" ;
label define AFDCTOT   -3 "MISSING" ;
label define AFDCCHIL  -3 "MISSING" ;
label define AFDCFAM   -3 "MISSING" ;
label define BIRTHS    -3 "MISSING" ;
label define BIRTHRAT  -3.0 "MISSING" ;
label define BIRTHYNG  -3 "MISSING" ;
label define BIRTHADO  -3 "MISSING" ;
label define BIRTH15   -3 "MISSING" ;
label define DEATHS    -3 "MISSING" ;
label define DEATHRAT  -3.0 "MISSING" ;
label define MVDEATH   -3 "MISSING" ;
label define INFDEATH  -3.0 "MISSING" ;
label define MARRIAGE  -3 "MISSING" ;
label define MARRATE   -3.0 "MISSING" ;
label define DIVORCES  -3 "MISSING" ;
label define DIVRATE   -3.0 "MISSING" ;
label define SUICIDES  -3 "MISSING" ;
label define NCHSPOP   -3 "MISSING" ;
label define ASUICRAT  -3.0 "MISSING" ;
label define SUICRATE  -3.0 "MISSING" ;
label define TFILING   -3 "MISSING" ;
label define TCHAP7    -3 "MISSING" ;
label define TCHAP11   -3 "MISSING" ;
label define TCHAP12   -3 "MISSING" ;
label define TCHAP13   -3 "MISSING" ;
label define BFILING   -3 "MISSING" ;
label define BCHAP7    -3 "MISSING" ;
label define BCHAP11   -3 "MISSING" ;
label define BCHAP12   -3 "MISSING" ;
label define BCHAP13   -3 "MISSING" ;
label define NBFILING  -3 "MISSING" ;
label define NBCHAP7   -3 "MISSING" ;
label define NBCHAP11  -3 "MISSING" ;
label define NBCHAP13  -3 "MISSING" ;
label define ID        -3 "MISSING" ;
label define MULTCO    1 "YES" 2 "NO" ;
label define CONAME    1 "Adams" 2 "Anoka" 3 "Atlantic" 4 "Boone"
                       5 "Bossier Parish" 6 "Cabarrus" 7 "Camden" 8 "Canyon"
                       9 "Centre" 10 "Chesapeake City" 11 "Chippewa"
                       12 "Cibola" 13 "Clark" 14 "Clay" 15 "Clinton"
                       16 "Contra Costa" 17 "Cook" 18 "Cumberland"
                       19 "Cuyahoga" 20 "Dallas" 21 "Davidson" 22 "Davis"
                       23 "Denton" 24 "Dodge" 25 "DuPage" 26 "Elko"
                       27 "Essex" 28 "Fort Bend" 29 "Fremont" 30 "Fulton"
                       31 "Garfield" 32 "Greene" 33 "Grundy" 34 "Hall"
                       35 "Harrison" 36 "Hartford" 37 "Hennepin" 38 "Henrico"
                       39 "Hillsborough" 40 "Hinds" 41 "Honolulu"
                       42 "Jackson" 43 "Jefferson" 44 "Johnson" 45 "Kane"
                       46 "Kennebec" 47 "La Crosse" 48 "Lake" 49 "Lauderdale"
                       50 "Lawrence" 51 "Lenoir" 52 "Logan" 53 "Lycoming"
                       54 "Madison" 55 "Mecklenburg" 56 "Mecosta"
                       57 "Menominee" 58 "Nassau" 59 "Neshoba" 60 "New Haven"
                       61 "New London" 62 "Nolan" 63 "Orange" 64 "Passaic"
                       65 "Peoria" 66 "Pierce" 67 "Pope" 68 "Poquoson City"
                       69 "Portage" 70 "Porter" 71 "Providence" 72 "Ramsey"
                       73 "Rice" 74 "Riley" 75 "Salt Lake" 76 "San Mateo"
                       77 "San Patricio" 78 "Sandoval" 79 "Santa Clara"
                       80 "Santa Cruz" 81 "Scott" 82 "Scurry" 83 "St. Johns"
                       84 "St. Louis" 85 "St. Louis City" 86 "St. Lucie"
                       87 "Staunton city" 88 "Suffolk" 89 "Sullivan"
                       90 "Tama" 91 "Tarrant" 92 "Travis" 93 "Utah"
                       94 "Ventura" 95 "Vermilion" 96 "Wake" 97 "Will"
                       98 "Williamson" 99 "Woodbury" 100 "York" ;
label define STAB      1 "ALABAMA" 2 "ARKANSAS" 3 "CALIFORNIA" 4 "COLORADO"
                       5 "CONNECTICUT" 6 "FLORIDA" 7 "GEORGIA" 8 "HAWAII"
                       9 "IOWA" 10 "IDAHO" 11 "ILLINOIS" 12 "INDIANA"
                       13 "KANSAS" 14 "LOUISIANA" 15 "MASSACHUSETTS"
                       16 "MAINE" 17 "MICHIGAN" 18 "MINNESOTA" 19 "MISSOURI"
                       20 "MISSISSIPPI" 21 "NORTH CAROLINA" 22 "NEBRASKA"
                       23 "NEW HAMPSHIRE" 24 "NEW JERSEY" 25 "NEW MEXICO"
                       26 "NEVADA" 27 "NEW YORK" 28 "OHIO" 29 "OKLAHOMA"
                       30 "PENNSYLVANIA" 31 "RHODE ISLAND" 32 "TENNESSEE"
                       33 "TEXAS" 34 "UTAH" 35 "VIRGINIA" 36 "WISCONSIN" ;
label define UCRDATA   -3 "Missing" 1 "COUNTY" 2 "PLACE" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.\n
****************************************************************/

/*
replace CASEID = . if (CASEID == -3)
replace YEAR = . if (YEAR == -3)
replace BINGOIND = . if (BINGOIND == -3)
replace LOTTIND = . if (LOTTIND == -3)
replace PERIMIND = . if (PERIMIND == -3)
replace CASIND = . if (CASIND == -3)
replace STFP = . if (STFP == -3)
replace COFP = . if (COFP == -3)
replace CASSPEND = . if (CASSPEND == -3.0000)
replace PERISPND = . if (PERISPND == -3.0000)
replace BINGSPND = . if (BINGSPND == -3.0000)
replace LOTTSPND = . if (LOTTSPND == -3.0000)
replace POP1990 = . if (POP1990 == -3)
replace PERMRN = . if (PERMRN == -3.0000)
replace UCRPOP = . if (UCRPOP == -3)
replace CRIME = . if (CRIME == -3)
replace MCRIME = . if (MCRIME == -3)
replace MURDER = . if (MURDER == -3)
replace RAPE = . if (RAPE == -3)
replace ROBBERY = . if (ROBBERY == -3)
replace ASSAULT = . if (ASSAULT == -3)
replace BURGLARY = . if (BURGLARY == -3)
replace LARCENY = . if (LARCENY == -3)
replace MVTHEFT = . if (MVTHEFT == -3)
replace ARSON = . if (ARSON == -3)
replace TOTINC = . if (TOTINC == -3)
replace COPOP = . if (COPOP == -3)
replace PERINC = . if (PERINC == -3)
replace EARNCONS = . if (EARNCONS == -3)
replace EARNTRAN = . if (EARNTRAN == -3)
replace EARNRET = . if (EARNRET == -3)
replace EARNGEN = . if (EARNGEN == -3)
replace EARNEAT = . if (EARNEAT == -3)
replace EARNSERV = . if (EARNSERV == -3)
replace EARNHOTL = . if (EARNHOTL == -3)
replace EARNRECR = . if (EARNRECR == -3)
replace EARNSOCS = . if (EARNSOCS == -3)
replace EARNGOVT = . if (EARNGOVT == -3)
replace EMPLOYED = . if (EMPLOYED == -3)
replace EMPCONST = . if (EMPCONST == -3)
replace EMPTRANS = . if (EMPTRANS == -3)
replace EMPRETTR = . if (EMPRETTR == -3)
replace EMPSERVC = . if (EMPSERVC == -3)
replace EMPGOVT = . if (EMPGOVT == -3)
replace INCTRANF = . if (INCTRANF == -3)
replace INCPERMT = . if (INCPERMT == -3)
replace INCUNEMP = . if (INCUNEMP == -3)
replace INCRETIR = . if (INCRETIR == -3)
replace INCDVINR = . if (INCDVINR == -3)
replace PERCAPNT = . if (PERCAPNT == -3)
replace PERCAPTP = . if (PERCAPTP == -3)
replace PERCAPIM = . if (PERCAPIM == -3)
replace PERCAPUI = . if (PERCAPUI == -3)
replace PERCAPRT = . if (PERCAPRT == -3)
replace FEDEXPI = . if (FEDEXPI == -3)
replace FEDEXRTD = . if (FEDEXRTD == -3)
replace FEDEXSAL = . if (FEDEXSAL == -3)
replace DOCTORS = . if (DOCTORS == -3)
replace HOSPBEDS = . if (HOSPBEDS == -3)
replace CIVLABF = . if (CIVLABF == -3)
replace UNEMPLOY = . if (UNEMPLOY == -3)
replace UNEMPRAT = . if (UNEMPRAT == -3.0)
replace AFDCTOT = . if (AFDCTOT == -3)
replace AFDCCHIL = . if (AFDCCHIL == -3)
replace AFDCFAM = . if (AFDCFAM == -3)
replace BIRTHS = . if (BIRTHS == -3)
replace BIRTHRAT = . if (BIRTHRAT == -3.0)
replace BIRTHYNG = . if (BIRTHYNG == -3)
replace BIRTHADO = . if (BIRTHADO == -3)
replace BIRTH15 = . if (BIRTH15 == -3)
replace DEATHS = . if (DEATHS == -3)
replace DEATHRAT = . if (DEATHRAT == -3.0)
replace MVDEATH = . if (MVDEATH == -3)
replace INFDEATH = . if (INFDEATH == -3.0)
replace MARRIAGE = . if (MARRIAGE == -3)
replace MARRATE = . if (MARRATE == -3.0)
replace DIVORCES = . if (DIVORCES == -3)
replace DIVRATE = . if (DIVRATE == -3.0)
replace SUICIDES = . if (SUICIDES == -3)
replace NCHSPOP = . if (NCHSPOP == -3)
replace ASUICRAT = . if (ASUICRAT == -3.0)
replace SUICRATE = . if (SUICRATE == -3.0)
replace TFILING = . if (TFILING == -3)
replace TCHAP7 = . if (TCHAP7 == -3)
replace TCHAP11 = . if (TCHAP11 == -3)
replace TCHAP12 = . if (TCHAP12 == -3)
replace TCHAP13 = . if (TCHAP13 == -3)
replace BFILING = . if (BFILING == -3)
replace BCHAP7 = . if (BCHAP7 == -3)
replace BCHAP11 = . if (BCHAP11 == -3)
replace BCHAP12 = . if (BCHAP12 == -3)
replace BCHAP13 = . if (BCHAP13 == -3)
replace NBFILING = . if (NBFILING == -3)
replace NBCHAP7 = . if (NBCHAP7 == -3)
replace NBCHAP11 = . if (NBCHAP11 == -3)
replace NBCHAP13 = . if (NBCHAP13 == -3)
replace ID = . if (ID == -3)
replace MULTCO = . if (MULTCO == -3)
replace UCRDATA = . if (UCRDATA == -3)


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

